//---------------------------------------------------------------------------

#ifndef HistoryH
#define HistoryH
//---------------------------------------------------------------------------

#include "common/Observable.h"
#include <string>
#include <deque>
#include <System.hpp>

class History: public Observable
{
public:
	enum { CALL_HISTORY_LIMIT = 1000 };
	struct Entry
	{
		struct Timestamp
		{
			unsigned short year, month, day, hour, min, sec, msec;
			Timestamp(void):
				year(0), month(0), day(0), hour(0), min(0), sec(0), msec(0)
			{
			}
			bool operator==(const Timestamp& right) const {
				return (
					year == right.year &&
					month == right.month &&
					day == right.day &&
					hour == right.hour &&
					min == right.min &&
					sec == right.sec &&
					msec == right.msec
				);
			}
		} timestamp;
		std::string uri;
		bool incoming;
		int time;	///< call time in seconds (starting from CONFIRMED state)

		bool operator==(const Entry& right) const {
			return (
				uri == right.uri &&
				incoming == right.incoming &&
				timestamp == right.timestamp
				);
		}
	};

	void AddEntry(Entry& entry);
private:
	std::deque<Entry> entries;
	AnsiString filename;
public:
	const std::deque<Entry>& GetEntries(void) const
	{
		return entries;
	}
	void SetFilename(AnsiString name)
	{
		filename = name;
	}
	int Read(void);
	int Write(void);
};

/** \brief Class of object passed to registered observers
*/
class HistoryNotifyArgument: public Argument
{
public:
	int dummy;
	//History::Entry &entry;
};

#endif
